@@ -1,12 +1,11 @@
 #[cfg(test)]
-
 #[allow(non_snake_case)]
 
 mod test {
     use std::fs;
     use std::io;
-    use std::process::Command;
     use std::path::Path;
+    use std::process::Command;
 
     use tempfile::tempdir;
 
@@ -20,7 +19,7 @@ mod test {
             .status()
             .expect("failed to run o-o");
 
-        assert_eq!(status.code().unwrap(), 1);
+        assert_eq!(status.code().unwrap(), 0);
     }
 
     #[test]
@@ -33,12 +32,12 @@ mod test {
         let _ = fs::write(SU(&file_a), "file a.\n")?;
 
         let temp_file = temp_dir.path().join("ls-output.txt");
-        let output = Command::new("./target/debug/o-o").args(
-            ["-d", SU(&temp_dir.path()), "-", SU(&temp_file), "-", "ls"])
+        let output = Command::new("./target/debug/o-o")
+            .args(["-d", SU(&temp_dir.path()), "-", SU(&temp_file), "-", "ls"])
             .output()?;
 
         assert_eq!(output.status.code().unwrap(), 0);
-        
+
         let temp_file_contents = fs::read_to_string(SU(&temp_file))?;
         assert!(temp_file_contents.find(FILE_A).is_some());
 
@@ -52,8 +51,16 @@ mod test {
     fn run_ls_with_wrong_option() -> Result<(), io::Error> {
         let temp_dir = tempdir()?;
 
-        let status = Command::new("./target/debug/o-o").args(
-            ["-d", SU(&temp_dir.path()), "-", "-", "-", "ls", "--a-option-ls-must-not-have"])
+        let status = Command::new("./target/debug/o-o")
+            .args([
+                "-d",
+                SU(&temp_dir.path()),
+                "-",
+                "-",
+                "-",
+                "ls",
+                "--a-option-ls-must-not-have",
+            ])
             .status()?;
 
         assert!(status.code().unwrap() != 0);
@@ -71,8 +78,16 @@ mod test {
         let file_a = temp_dir.path().join(FILE_A);
         let _ = fs::write(SU(&file_a), "1st line\n2nd line\n3rd line\n")?;
 
-        let output = Command::new("./target/debug/o-o").args(
-            ["-d", SU(&temp_dir.path()), SU(&file_a), "-", "-", "cat", SU(&file_a)])
+        let output = Command::new("./target/debug/o-o")
+            .args([
+                "-d",
+                SU(&temp_dir.path()),
+                SU(&file_a),
+                "-",
+                "-",
+                "cat",
+                SU(&file_a),
+            ])
             .output()?;
 
         assert!(output.status.code().unwrap() == 0);
@@ -95,8 +110,16 @@ mod test {
 
         let out_file = temp_dir.path().join("out.txt");
         let err_file = temp_dir.path().join("err.txt");
-        let status = Command::new("./target/debug/o-o").args(
-            ["-d", SU(&temp_dir.path()), "-", SU(&out_file), SU(&err_file), "bash", SU(&script)])
+        let status = Command::new("./target/debug/o-o")
+            .args([
+                "-d",
+                SU(&temp_dir.path()),
+                "-",
+                SU(&out_file),
+                SU(&err_file),
+                "bash",
+                SU(&script),
+            ])
             .status()?;
 
         assert!(status.code().unwrap() == 0);
@@ -122,8 +145,16 @@ mod test {
         let script = temp_dir.path().join(SCRIPT);
         let _ = fs::write(SU(&script), "echo \"stdout\" >&1\necho \"stderr\" >&2\n")?;
 
-        let output = Command::new("./target/debug/o-o").args(
-            ["-d", SU(&temp_dir.path()), "-", "-", "=", "bash", SU(&script)])
+        let output = Command::new("./target/debug/o-o")
+            .args([
+                "-d",
+                SU(&temp_dir.path()),
+                "-",
+                "-",
+                "=",
+                "bash",
+                SU(&script),
+            ])
             .output()?;
 
         assert!(output.status.code().unwrap() == 0);
@@ -143,13 +174,29 @@ mod test {
         let out_file = temp_dir.path().join("out.txt");
         let append_out_file = format!("+{}", SU(&out_file));
 
-        let status1 = Command::new("./target/debug/o-o").args(
-            ["-d", SU(&temp_dir.path()), "-", &append_out_file, "-", "echo", "1st line"])
+        let status1 = Command::new("./target/debug/o-o")
+            .args([
+                "-d",
+                SU(&temp_dir.path()),
+                "-",
+                &append_out_file,
+                "-",
+                "echo",
+                "1st line",
+            ])
             .status()?;
         assert!(status1.code().unwrap() == 0);
-        
-        let status2 = Command::new("./target/debug/o-o").args(
-            ["-d", SU(&temp_dir.path()), "-", &append_out_file, "-", "echo", "2ne line"])
+
+        let status2 = Command::new("./target/debug/o-o")
+            .args([
+                "-d",
+                SU(&temp_dir.path()),
+                "-",
+                &append_out_file,
+                "-",
+                "echo",
+                "2ne line",
+            ])
             .status()?;
         assert!(status2.code().unwrap() == 0);
 
@@ -170,11 +217,11 @@ mod test {
         let file_a = temp_dir.path().join(FILE_A);
         let _ = fs::write(SU(&file_a), "file a.\n")?;
 
-        let status = Command::new("./target/debug/o-o").args(
-            ["-d", SU(&temp_dir.path()), SU(&file_a), "=", "-", "wc"])
+        let status = Command::new("./target/debug/o-o")
+            .args(["-d", SU(&temp_dir.path()), SU(&file_a), "=", "-", "wc"])
             .status()?;
         assert!(status.code().unwrap() == 0);
-        
+
         let file_a_contents = fs::read_to_string(SU(&file_a))?;
         assert!(file_a_contents.find("1").is_some());
 
@@ -191,8 +238,21 @@ mod test {
         let file_a = temp_dir.path().join(FILE_A);
         let _ = fs::write(SU(&file_a), "1st line\n2nd line\n3rd line\n")?;
 
-        let output = Command::new("./target/debug/o-o").args(
-            ["-d", SU(&temp_dir.path()), "-p", "P", SU(&file_a), "-", "-", "cat", SU(&file_a), "P", "wc", "-l"])
+        let output = Command::new("./target/debug/o-o")
+            .args([
+                "-d",
+                SU(&temp_dir.path()),
+                "-p",
+                "P",
+                SU(&file_a),
+                "-",
+                "-",
+                "cat",
+                SU(&file_a),
+                "P",
+                "wc",
+                "-l",
+            ])
             .output()?;
 
         assert!(output.status.code().unwrap() == 0);
@@ -212,19 +272,30 @@ mod test {
         let temp_dir = tempdir()?;
 
         let script_echo_and_fail = temp_dir.path().join(SCRIPT_ECHO_AND_FAIL);
-        let _ = fs::write(SU(&script_echo_and_fail), "#!/bin/bash\n\necho \"echo and fail!\"\nexit 12\n")?;
+        let _ = fs::write(
+            SU(&script_echo_and_fail),
+            "#!/bin/bash\n\necho \"echo and fail!\"\nexit 12\n",
+        )?;
 
         let file_a = temp_dir.path().join(FILE_A);
         let _ = fs::write(SU(&file_a), "file a original contents\n")?;
 
-        let status = Command::new("./target/debug/o-o").args(
-            ["-d", SU(&temp_dir.path()), SU(&file_a), "=", "-", "bash", SU(&script_echo_and_fail)])
+        let status = Command::new("./target/debug/o-o")
+            .args([
+                "-d",
+                SU(&temp_dir.path()),
+                SU(&file_a),
+                "=",
+                "-",
+                "bash",
+                SU(&script_echo_and_fail),
+            ])
             .status()?;
         assert!(status.code().unwrap() == 12);
-        
+
         let file_a_contents = fs::read_to_string(SU(&file_a))?;
         assert!(file_a_contents.find("original contents").is_some());
-        assert!(! file_a_contents.find("echo and fail!").is_some());
+        assert!(!file_a_contents.find("echo and fail!").is_some());
 
         temp_dir.close()?;
         Ok(())
@@ -238,18 +309,30 @@ mod test {
         let temp_dir = tempdir()?;
 
         let script_echo_and_fail = temp_dir.path().join(SCRIPT_ECHO_AND_FAIL);
-        let _ = fs::write(SU(&script_echo_and_fail), "#!/bin/bash\n\necho \"echo and fail!\"\nexit 12\n")?;
+        let _ = fs::write(
+            SU(&script_echo_and_fail),
+            "#!/bin/bash\n\necho \"echo and fail!\"\nexit 12\n",
+        )?;
 
         let file_a = temp_dir.path().join(FILE_A);
         let _ = fs::write(SU(&file_a), "file a original contents\n")?;
 
-        let status = Command::new("./target/debug/o-o").args(
-            ["-F", "-d", SU(&temp_dir.path()), SU(&file_a), "=", "-", "bash", SU(&script_echo_and_fail)])
+        let status = Command::new("./target/debug/o-o")
+            .args([
+                "-F",
+                "-d",
+                SU(&temp_dir.path()),
+                SU(&file_a),
+                "=",
+                "-",
+                "bash",
+                SU(&script_echo_and_fail),
+            ])
             .status()?;
         assert!(status.code().unwrap() == 12);
-        
+
         let file_a_contents = fs::read_to_string(SU(&file_a))?;
-        assert!(! file_a_contents.find("original contents").is_some());
+        assert!(!file_a_contents.find("original contents").is_some());
         assert!(file_a_contents.find("echo and fail!").is_some());
 
         temp_dir.close()?;
@@ -265,8 +348,18 @@ mod test {
         let script = temp_dir.path().join(SCRIPT);
         let _ = fs::write(SU(&script), "echo $V\n")?;
 
-        let output = Command::new("./target/debug/o-o").args(
-            ["-d", SU(&temp_dir.path()), "-e", "V=some", "-", "-", "-", "bash", SU(&script)])
+        let output = Command::new("./target/debug/o-o")
+            .args([
+                "-d",
+                SU(&temp_dir.path()),
+                "-e",
+                "V=some",
+                "-",
+                "-",
+                "-",
+                "bash",
+                SU(&script),
+            ])
             .output()?;
 
         assert!(output.status.code().unwrap() == 0);
@@ -282,14 +375,14 @@ mod test {
     fn stdout_devnull() -> Result<(), io::Error> {
         let temp_dir = tempdir()?;
 
-        let output = Command::new("./target/debug/o-o").args(
-            ["-d", SU(&temp_dir.path()), "-", ".", "-", "echo", "hello"])
+        let output = Command::new("./target/debug/o-o")
+            .args(["-d", SU(&temp_dir.path()), "-", ".", "-", "echo", "hello"])
             .output()?;
 
         assert!(output.status.code().unwrap() == 0);
 
         let output_contents = String::from_utf8(output.stdout).unwrap();
-        assert!(! output_contents.find("hello").is_some());
+        assert!(!output_contents.find("hello").is_some());
 
         temp_dir.close()?;
         Ok(())
@@ -302,10 +395,21 @@ mod test {
         let temp_dir = tempdir()?;
 
         let script = temp_dir.path().join(SCRIPT);
-        let _ = fs::write(SU(&script), "echo !!If you see this message, the test \"stderr_devnull\" failed.!! >&2\n")?;
+        let _ = fs::write(
+            SU(&script),
+            "echo !!If you see this message, the test \"stderr_devnull\" failed.!! >&2\n",
+        )?;
 
-        let output = Command::new("./target/debug/o-o").args(
-            ["-d", SU(&temp_dir.path()), "-", "-", ".", "bash", SU(&script)])
+        let output = Command::new("./target/debug/o-o")
+            .args([
+                "-d",
+                SU(&temp_dir.path()),
+                "-",
+                "-",
+                ".",
+                "bash",
+                SU(&script),
+            ])
             .output()?;
 
         assert!(output.status.code().unwrap() == 0);
